module ApplicationHelper
  
  def link_to_if_authorized(name, options = {}, html_options = nil, *parameters)
    options[:action] = :index if options[:action].nil?
    return(link_to(name, options, html_options, *parameters) if is_allowed_to?(options[:controller] || params[:controller], options[:action]))
  end
  
  def time_tag(time)
    if time.nil? or !(time.is_a?(Time))
      text = ""
    else
      text = t(:label_time_ago, :time => distance_of_time_in_words(Time.now, time))
      text = content_tag(:acronym, text, :title => format_time(time))
    end
    return(text)
  end
  
  def format_time(time)
    return(time.strftime("%Y/%m/%d %H:%M:%S"))
  end

  def format_percentaje(value)
    return("%.0f%%" % (value * 100.0))
  end

  def tool_bar(text_area_id)
    text = content_tag(:span) do
      tool_bar_button(text_area_id, "bold", "*", "*") + " " +
      tool_bar_button(text_area_id, "italic", "_", "_") + " " +
      tool_bar_button(text_area_id, "underline", "+", "+") + " " +
      tool_bar_button(text_area_id, "crossed", "-", "-") + " " +
      tool_bar_button(text_area_id, "code", "@", "@") + " " +
      tool_bar_button(text_area_id, "pre", "<pre><code>", "</code></pre>") + " " +
      tool_bar_button(text_area_id, "h1", "h1. ", "") + " " +
      tool_bar_button(text_area_id, "h2", "h2. ", "") + " " +
      tool_bar_button(text_area_id, "h3", "h3. ", "") + " " +
      tool_bar_button(text_area_id, "list_ordered", "# ", "") + " " +
      tool_bar_button(text_area_id, "list_unordered", "* ", "") + " " +
      tool_bar_button(text_area_id, "tab_add", "> ", "") + " " +
      tool_bar_button(text_area_id, "link", "http://", "") + " " +
      tool_bar_button(text_area_id, "image", "!", "!")
    end
    text += tag(:br)
    return(raw(text))
  end

  def tool_bar_button(text_area_id, button, prefix, sufix)
    text = link_to_function(image_tag("icon_#{button}.png"),
                            "surroundText('#{text_area_id}', '#{prefix}', '#{sufix}')",
                            :title => t("label_tool_bar_button_#{button}"))
    return(text)
  end

  def google_font_link_tag(family)
    family = family.split(" ").compact.join("+")
    return(tag("link",
           {:rel => :stylesheet,
            :type => Mime::CSS,
            :href => "http://fonts.googleapis.com/css?family=#{family}"},
           false,
           false))
  end

end
